pub struct UpdateReservationRecord {
pub reservation: Option<Box<Reservation>>,
pub warnings: Option<Vec<Warning>>,
pub errors: Option<Vec<Error>>,
}Expand description
UpdateReservationRecord : UpdateReservationRecord entity contains the Reservation if there is an error/warning while performing the requested operation on it, otherwise it will contain the new reservationId.
Fields
reservation: Option<Box<Reservation>>warnings: Option<Vec<Warning>>A list of warnings returned in the sucessful execution response of an API request.
errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl UpdateReservationRecord
impl UpdateReservationRecord
sourcepub fn new() -> UpdateReservationRecord
pub fn new() -> UpdateReservationRecord
UpdateReservationRecord entity contains the Reservation if there is an error/warning while performing the requested operation on it, otherwise it will contain the new reservationId.